@@ -224,7 +224,7 @@ pub type glDrawElementsInstanced_t = unsafe extern "system" fn(mode: GLenum, cou
 pub type glEnable_t = extern "system" fn(cap: GLenum);
 
 /// [glEnableVertexAttribArray](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glEnableVertexAttribArray.xhtml)
-pub type glEnableVertexAttribArray_t = extern "system" fn(vaobj: GLuint, index: GLuint);
+pub type glEnableVertexAttribArray_t = extern "system" fn(index: GLuint);
 
 /// [glFramebufferRenderbuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glFramebufferRenderbuffer.xhtml)
 pub type glFramebufferRenderbuffer_t = extern "system" fn(target: GLenum, attachment: GLenum, renderbuffertarget: GLenum, renderbuffer: GLuint);
