@@ -227,77 +227,93 @@ impl GlFns {
 impl GlFns {
   /// [glActiveTexture](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glActiveTexture.xhtml)
   #[inline]
-  pub fn ActiveTexture(&self, texture: GLenum)  {
+  pub fn ActiveTexture(&self, texture: GLenum) {
     (self.glActiveTexture_p)(texture)
   }
   /// [glAttachShader](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glAttachShader.xhtml)
   #[inline]
-  pub fn AttachShader(&self, program: GLuint, shader: GLuint)  {
+  pub fn AttachShader(&self, program: GLuint, shader: GLuint) {
     (self.glAttachShader_p)(program, shader)
   }
   /// [glBindBuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBindBuffer.xhtml)
   #[inline]
-  pub fn BindBuffer(&self, target: GLenum, buffer: GLuint)  {
+  pub fn BindBuffer(&self, target: GLenum, buffer: GLuint) {
     (self.glBindBuffer_p)(target, buffer)
   }
   /// [glBindBufferBase](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBindBufferBase.xhtml)
   #[inline]
-  pub unsafe fn BindBufferBase(&self, target: GLenum, index: GLuint, buffer: GLuint)  {
+  pub unsafe fn BindBufferBase(
+    &self, target: GLenum, index: GLuint, buffer: GLuint,
+  ) {
     (self.glBindBufferBase_p)(target, index, buffer)
   }
   /// [glBindBufferRange](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBindBufferRange.xhtml)
   #[inline]
-  pub unsafe fn BindBufferRange(&self, target: GLenum, index: GLuint, buffer: GLuint, offset: GLintptr, size: GLsizeiptr)  {
+  pub unsafe fn BindBufferRange(
+    &self, target: GLenum, index: GLuint, buffer: GLuint, offset: GLintptr,
+    size: GLsizeiptr,
+  ) {
     (self.glBindBufferRange_p)(target, index, buffer, offset, size)
   }
   /// [glBindFramebuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBindFramebuffer.xhtml)
   #[inline]
-  pub unsafe fn BindFramebuffer(&self, target: GLenum, framebuffer: GLuint)  {
+  pub unsafe fn BindFramebuffer(&self, target: GLenum, framebuffer: GLuint) {
     (self.glBindFramebuffer_p)(target, framebuffer)
   }
   /// [glBindRenderbuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBindRenderbuffer.xhtml)
   #[inline]
-  pub fn BindRenderbuffer(&self, target: GLenum, renderbuffer: GLuint)  {
+  pub fn BindRenderbuffer(&self, target: GLenum, renderbuffer: GLuint) {
     (self.glBindRenderbuffer_p)(target, renderbuffer)
   }
   /// [glBindTexture](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBindTexture.xhtml)
   #[inline]
-  pub fn BindTexture(&self, target: GLenum, texture: GLuint)  {
+  pub fn BindTexture(&self, target: GLenum, texture: GLuint) {
     (self.glBindTexture_p)(target, texture)
   }
   /// [glBindVertexArray](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBindVertexArray.xhtml)
   #[inline]
-  pub fn BindVertexArray(&self, array: GLuint)  {
+  pub fn BindVertexArray(&self, array: GLuint) {
     (self.glBindVertexArray_p)(array)
   }
   /// [glBlendEquation](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBlendEquation.xhtml)
   #[inline]
-  pub fn BlendEquation(&self, mode: GLenum)  {
+  pub fn BlendEquation(&self, mode: GLenum) {
     (self.glBlendEquation_p)(mode)
   }
   /// [glBlendFunc](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBlendFunc.xhtml)
   #[inline]
-  pub fn BlendFunc(&self, sfactor: GLenum, dfactor: GLenum)  {
+  pub fn BlendFunc(&self, sfactor: GLenum, dfactor: GLenum) {
     (self.glBlendFunc_p)(sfactor, dfactor)
   }
   /// [glBlendFunci](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBlendFunc.xhtml)
   #[inline]
-  pub fn BlendFunci(&self, buf: GLuint, sfactor: GLenum, dfactor: GLenum)  {
+  pub fn BlendFunci(&self, buf: GLuint, sfactor: GLenum, dfactor: GLenum) {
     (self.glBlendFunci_p)(buf, sfactor, dfactor)
   }
   /// [glBlitFramebuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBlitFramebuffer.xhtml)
   #[inline]
-  pub unsafe fn BlitFramebuffer(&self, srcX0: GLint, srcY0: GLint, srcX1: GLint, srcY1: GLint, dstX0: GLint, dstY0: GLint, dstX1: GLint, dstY1: GLint, mask: GLbitfield, filter: GLenum)  {
-    (self.glBlitFramebuffer_p)(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter)
+  pub unsafe fn BlitFramebuffer(
+    &self, srcX0: GLint, srcY0: GLint, srcX1: GLint, srcY1: GLint,
+    dstX0: GLint, dstY0: GLint, dstX1: GLint, dstY1: GLint, mask: GLbitfield,
+    filter: GLenum,
+  ) {
+    (self.glBlitFramebuffer_p)(
+      srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter,
+    )
   }
   /// [glBufferData](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBufferData.xhtml)
   #[inline]
-  pub unsafe fn BufferData(&self, target: GLenum, size: GLsizeiptr, data: *const void, usage: GLenum)  {
+  pub unsafe fn BufferData(
+    &self, target: GLenum, size: GLsizeiptr, data: *const void, usage: GLenum,
+  ) {
     (self.glBufferData_p)(target, size, data, usage)
   }
   /// [glBufferSubData](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glBufferSubData.xhtml)
   #[inline]
-  pub unsafe fn BufferSubData(&self, target: GLenum, offset: GLintptr, size: GLsizeiptr, data: *const void)  {
+  pub unsafe fn BufferSubData(
+    &self, target: GLenum, offset: GLintptr, size: GLsizeiptr,
+    data: *const void,
+  ) {
     (self.glBufferSubData_p)(target, offset, size, data)
   }
   /// [glCheckFramebufferStatus](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glCheckFramebufferStatus.xhtml)
@@ -316,8 +332,8 @@ impl GlFns {
   ///   * `GL_DEPTH_BUFFER_BIT`
   ///   * `GL_STENCIL_BUFFER_BIT`
   ///
-  /// Multiple color buffers can be cleared simultaneously by selecting more than
-  /// one buffer at a time using [DrawBuffer](Self::DrawBuffer).
+  /// Multiple color buffers can be cleared simultaneously by selecting more
+  /// than one buffer at a time using [DrawBuffer](Self::DrawBuffer).
   ///
   /// The pixel ownership test, the scissor test, dithering, and the buffer
   /// writemasks affect the operation of `Clear`. The scissor box bounds the
@@ -328,12 +344,14 @@ impl GlFns {
   /// * `GL_INVALID_VALUE` is generated if any bit other than the three defined
   ///   bits is set in `mask`.
   #[inline]
-  pub fn Clear(&self, mask: GLbitfield)  {
+  pub fn Clear(&self, mask: GLbitfield) {
     (self.glClear_p)(mask)
   }
   /// [glClearBufferfv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glClearBuffer.xhtml)
   #[inline]
-  pub unsafe fn ClearBufferfv(&self, buffer: GLenum, drawbuffer: GLint, value: *const GLfloat)  {
+  pub unsafe fn ClearBufferfv(
+    &self, buffer: GLenum, drawbuffer: GLint, value: *const GLfloat,
+  ) {
     (self.glClearBufferfv_p)(buffer, drawbuffer, value)
   }
   /// [glClearColor](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glClearColor.xhtml) (GL 1.0, GLES 2.0)
@@ -346,18 +364,20 @@ impl GlFns {
   /// ## Associated Gets
   /// * `GL_COLOR_CLEAR_VALUE`
   #[inline]
-  pub fn ClearColor(&self, red: GLfloat, green: GLfloat, blue: GLfloat, alpha: GLfloat)  {
+  pub fn ClearColor(
+    &self, red: GLfloat, green: GLfloat, blue: GLfloat, alpha: GLfloat,
+  ) {
     (self.glClearColor_p)(red, green, blue, alpha)
   }
   /// [glClearDepth](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glClearDepth.xhtml) (GL 1.0, GLES -)
   ///
-  /// Specifies the depth value used when the depth buffer is cleared. The initial
-  /// value is 1.0
+  /// Specifies the depth value used when the depth buffer is cleared. The
+  /// initial value is 1.0
   ///
   /// ## Associated Gets
   /// * `GL_DEPTH_CLEAR_VALUE`
   #[inline]
-  pub fn ClearDepth(&self, depth: GLdouble)  {
+  pub fn ClearDepth(&self, depth: GLdouble) {
     (self.glClearDepth_p)(depth)
   }
   /// [glClearStencil](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glClearStencil.xhtml) (GL 1.0, GLES 2.0)
@@ -365,24 +385,24 @@ impl GlFns {
   /// Specifies the index used when the stencil buffer is cleared. The initial
   /// value is 0.
   ///
-  /// The input is masked with `2**m - 1`, where `m` is the number of bits in the
-  /// stencil buffer.
+  /// The input is masked with `2**m - 1`, where `m` is the number of bits in
+  /// the stencil buffer.
   ///
   /// ## Associated Gets
   /// * `GL_STENCIL_CLEAR_VALUE`
   /// * `GL_STENCIL_BITS`
   #[inline]
-  pub fn ClearStencil(&self, s: GLint)  {
+  pub fn ClearStencil(&self, s: GLint) {
     (self.glClearStencil_p)(s)
   }
   /// [glCompileShader](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glCompileShader.xhtml)
   #[inline]
-  pub fn CompileShader(&self, shader: GLuint)  {
+  pub fn CompileShader(&self, shader: GLuint) {
     (self.glCompileShader_p)(shader)
   }
   /// [glCreateProgram](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glCreateProgram.xhtml)
   #[inline]
-  pub fn CreateProgram(&self, ) -> GLuint {
+  pub fn CreateProgram(&self) -> GLuint {
     (self.glCreateProgram_p)()
   }
   /// [glCreateShader](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glCreateShader.xhtml)
@@ -392,200 +412,250 @@ impl GlFns {
   }
   /// [glCullFace](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glCullFace.xhtml)
   #[inline]
-  pub fn CullFace(&self, mode: GLenum)  {
+  pub fn CullFace(&self, mode: GLenum) {
     (self.glCullFace_p)(mode)
   }
   /// [glDebugMessageCallback](https://www.khronos.org/registry/OpenGL/extensions/KHR/KHR_debug.txt) (GL_KHR_debug, GL 4.3, GLES 3.2)
   ///
   /// Called by the GL driver to notify the program of various events.
   #[inline]
-  pub unsafe fn DebugMessageCallback(&self, callback: Option<GLDEBUGPROC>, userParam: *const void)  {
-    if let Some(f) = self.glDebugMessageCallback_p { f(callback, userParam) }
+  pub unsafe fn DebugMessageCallback(
+    &self, callback: Option<GLDEBUGPROC>, userParam: *const void,
+  ) {
+    if let Some(f) = self.glDebugMessageCallback_p {
+      f(callback, userParam)
+    }
   }
   /// [glDebugMessageControl](https://www.khronos.org/registry/OpenGL/extensions/KHR/KHR_debug.txt) (GL_KHR_debug, GL 4.3, GLES 3.2)
   ///
   /// Allows the program to set filters on what events will trigger the debug
   /// callback.
   #[inline]
-  pub unsafe fn DebugMessageControl(&self, source: GLenum, type_: GLenum, severity: GLenum, count: GLsizei, ids: *const GLuint, enabled: GLboolean)  {
-    if let Some(f) = self.glDebugMessageControl_p { f(source, type_, severity, count, ids, enabled) }
+  pub unsafe fn DebugMessageControl(
+    &self, source: GLenum, type_: GLenum, severity: GLenum, count: GLsizei,
+    ids: *const GLuint, enabled: GLboolean,
+  ) {
+    if let Some(f) = self.glDebugMessageControl_p {
+      f(source, type_, severity, count, ids, enabled)
+    }
   }
   /// [glDebugMessageInsert](https://www.khronos.org/registry/OpenGL/extensions/KHR/KHR_debug.txt) (GL_KHR_debug, GL 4.3, GLES 3.2)
   ///
-  /// Allows the program to send a debug event to the driver, which will then call
-  /// the callback (if the event isn't filtered).
+  /// Allows the program to send a debug event to the driver, which will then
+  /// call the callback (if the event isn't filtered).
   #[inline]
-  pub unsafe fn DebugMessageInsert(&self, source: GLenum, type_: GLenum, id: GLuint, severity: GLenum, length: GLint, buf: *const u8)  {
-    if let Some(f) = self.glDebugMessageInsert_p { f(source, type_, id, severity, length, buf) }
+  pub unsafe fn DebugMessageInsert(
+    &self, source: GLenum, type_: GLenum, id: GLuint, severity: GLenum,
+    length: GLint, buf: *const u8,
+  ) {
+    if let Some(f) = self.glDebugMessageInsert_p {
+      f(source, type_, id, severity, length, buf)
+    }
   }
   /// [glDeleteBuffers](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDeleteBuffers.xhtml)
   #[inline]
-  pub unsafe fn DeleteBuffers(&self, n: GLsizei, buffers: *const GLuint)  {
+  pub unsafe fn DeleteBuffers(&self, n: GLsizei, buffers: *const GLuint) {
     (self.glDeleteBuffers_p)(n, buffers)
   }
   /// [glDeleteFramebuffers](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDeleteFramebuffers.xhtml)
   #[inline]
-  pub unsafe fn DeleteFramebuffers(&self, n: GLsizei, framebuffers: *mut GLuint)  {
+  pub unsafe fn DeleteFramebuffers(
+    &self, n: GLsizei, framebuffers: *mut GLuint,
+  ) {
     (self.glDeleteFramebuffers_p)(n, framebuffers)
   }
   /// [glDeleteProgram](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDeleteProgram.xhtml)
   #[inline]
-  pub fn DeleteProgram(&self, program: GLuint)  {
+  pub fn DeleteProgram(&self, program: GLuint) {
     (self.glDeleteProgram_p)(program)
   }
   /// [glDeleteShader](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDeleteShader.xhtml)
   #[inline]
-  pub fn DeleteShader(&self, shader: GLuint)  {
+  pub fn DeleteShader(&self, shader: GLuint) {
     (self.glDeleteShader_p)(shader)
   }
   /// [glDeleteTextures](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDeleteTextures.xhtml)
   #[inline]
-  pub unsafe fn DeleteTextures(&self, n: GLsizei, textures: *const GLuint)  {
+  pub unsafe fn DeleteTextures(&self, n: GLsizei, textures: *const GLuint) {
     (self.glDeleteTextures_p)(n, textures)
   }
   /// [glDeleteVertexArrays](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDeleteVertexArrays.xhtml)
   #[inline]
-  pub unsafe fn DeleteVertexArrays(&self, n: GLsizei, arrays: *const GLuint)  {
+  pub unsafe fn DeleteVertexArrays(&self, n: GLsizei, arrays: *const GLuint) {
     (self.glDeleteVertexArrays_p)(n, arrays)
   }
   /// [glDepthFunc](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDepthFunc.xhtml)
   #[inline]
-  pub fn DepthFunc(&self, func: GLenum)  {
+  pub fn DepthFunc(&self, func: GLenum) {
     (self.glDepthFunc_p)(func)
   }
   /// [glDepthMask](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDepthMask.xhtml)
   #[inline]
-  pub fn DepthMask(&self, flag: GLboolean)  {
+  pub fn DepthMask(&self, flag: GLboolean) {
     (self.glDepthMask_p)(flag)
   }
   /// [glDisable](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDisable.xhtml)
   #[inline]
-  pub fn Disable(&self, cap: GLenum)  {
+  pub fn Disable(&self, cap: GLenum) {
     (self.glDisable_p)(cap)
   }
   /// [glDrawArrays](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDrawArrays.xhtml)
   #[inline]
-  pub unsafe fn DrawArrays(&self, mode: GLenum, first: GLint, count: GLsizei)  {
+  pub unsafe fn DrawArrays(&self, mode: GLenum, first: GLint, count: GLsizei) {
     (self.glDrawArrays_p)(mode, first, count)
   }
   /// [glDrawArraysInstanced](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDrawArraysInstanced.xhtml)
   #[inline]
-  pub unsafe fn DrawArraysInstanced(&self, mode: GLenum, first: GLint, count: GLsizei, instancecount: GLsizei)  {
+  pub unsafe fn DrawArraysInstanced(
+    &self, mode: GLenum, first: GLint, count: GLsizei, instancecount: GLsizei,
+  ) {
     (self.glDrawArraysInstanced_p)(mode, first, count, instancecount)
   }
   /// [glDrawBuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDrawBuffer.xhtml)
   #[inline]
-  pub fn DrawBuffer(&self, buf: GLenum)  {
+  pub fn DrawBuffer(&self, buf: GLenum) {
     (self.glDrawBuffer_p)(buf)
   }
   /// [glDrawBuffers](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDrawBuffers.xhtml)
   #[inline]
-  pub unsafe fn DrawBuffers(&self, n: GLsizei, bufs: *const GLenum)  {
+  pub unsafe fn DrawBuffers(&self, n: GLsizei, bufs: *const GLenum) {
     (self.glDrawBuffers_p)(n, bufs)
   }
   /// [glDrawElements](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDrawElements.xhtml)
   #[inline]
-  pub unsafe fn DrawElements(&self, mode: GLenum, count: GLsizei, type_: GLenum, indices: *const void)  {
+  pub unsafe fn DrawElements(
+    &self, mode: GLenum, count: GLsizei, type_: GLenum, indices: *const void,
+  ) {
     (self.glDrawElements_p)(mode, count, type_, indices)
   }
   /// [glDrawElementsInstanced](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glDrawElementsInstanced.xhtml)
   #[inline]
-  pub unsafe fn DrawElementsInstanced(&self, mode: GLenum, count: GLsizei, type_: GLenum, indices: *const void, instancecount: GLsizei)  {
+  pub unsafe fn DrawElementsInstanced(
+    &self, mode: GLenum, count: GLsizei, type_: GLenum, indices: *const void,
+    instancecount: GLsizei,
+  ) {
     (self.glDrawElementsInstanced_p)(mode, count, type_, indices, instancecount)
   }
   /// [glEnable](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glEnable.xhtml)
   #[inline]
-  pub fn Enable(&self, cap: GLenum)  {
+  pub fn Enable(&self, cap: GLenum) {
     (self.glEnable_p)(cap)
   }
   /// [glEnableVertexAttribArray](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glEnableVertexAttribArray.xhtml)
   #[inline]
-  pub fn EnableVertexAttribArray(&self, vaobj: GLuint, index: GLuint)  {
-    (self.glEnableVertexAttribArray_p)(vaobj, index)
+  pub fn EnableVertexAttribArray(&self, index: GLuint) {
+    (self.glEnableVertexAttribArray_p)(index)
   }
   /// [glFramebufferRenderbuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glFramebufferRenderbuffer.xhtml)
   #[inline]
-  pub fn FramebufferRenderbuffer(&self, target: GLenum, attachment: GLenum, renderbuffertarget: GLenum, renderbuffer: GLuint)  {
-    (self.glFramebufferRenderbuffer_p)(target, attachment, renderbuffertarget, renderbuffer)
+  pub fn FramebufferRenderbuffer(
+    &self, target: GLenum, attachment: GLenum, renderbuffertarget: GLenum,
+    renderbuffer: GLuint,
+  ) {
+    (self.glFramebufferRenderbuffer_p)(
+      target,
+      attachment,
+      renderbuffertarget,
+      renderbuffer,
+    )
   }
   /// [glFramebufferTexture](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glFramebufferTexture.xhtml)
   #[inline]
-  pub fn FramebufferTexture(&self, target: GLenum, attachment: GLenum, texture: GLuint, level: GLint)  {
+  pub fn FramebufferTexture(
+    &self, target: GLenum, attachment: GLenum, texture: GLuint, level: GLint,
+  ) {
     (self.glFramebufferTexture_p)(target, attachment, texture, level)
   }
   /// [glFramebufferTexture2D](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glFramebufferTexture.xhtml)
   #[inline]
-  pub fn FramebufferTexture2D(&self, target: GLenum, attachment: GLenum, textarget: GLenum, texture: GLuint, level: GLint)  {
-    (self.glFramebufferTexture2D_p)(target, attachment, textarget, texture, level)
+  pub fn FramebufferTexture2D(
+    &self, target: GLenum, attachment: GLenum, textarget: GLenum,
+    texture: GLuint, level: GLint,
+  ) {
+    (self.glFramebufferTexture2D_p)(
+      target, attachment, textarget, texture, level,
+    )
   }
   /// [glFrontFace](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glFrontFace.xhtml)
   #[inline]
-  pub fn FrontFace(&self, mode: GLenum)  {
+  pub fn FrontFace(&self, mode: GLenum) {
     (self.glFrontFace_p)(mode)
   }
   /// [glGenBuffers](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGenBuffers.xhtml)
   #[inline]
-  pub unsafe fn GenBuffers(&self, n: GLsizei, buffers: *mut GLuint)  {
+  pub unsafe fn GenBuffers(&self, n: GLsizei, buffers: *mut GLuint) {
     (self.glGenBuffers_p)(n, buffers)
   }
   /// [glGenFramebuffers](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGenFramebuffers.xhtml)
   #[inline]
-  pub unsafe fn GenFramebuffers(&self, n: GLsizei, ids: *mut GLuint)  {
+  pub unsafe fn GenFramebuffers(&self, n: GLsizei, ids: *mut GLuint) {
     (self.glGenFramebuffers_p)(n, ids)
   }
   /// [glGenRenderbuffers](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGenRenderbuffers.xhtml)
   #[inline]
-  pub unsafe fn GenRenderbuffers(&self, n: GLsizei, renderbuffers: *mut GLuint)  {
+  pub unsafe fn GenRenderbuffers(
+    &self, n: GLsizei, renderbuffers: *mut GLuint,
+  ) {
     (self.glGenRenderbuffers_p)(n, renderbuffers)
   }
   /// [glGenTextures](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGenTextures.xhtml)
   #[inline]
-  pub unsafe fn GenTextures(&self, n: GLsizei, textures: *mut GLuint)  {
+  pub unsafe fn GenTextures(&self, n: GLsizei, textures: *mut GLuint) {
     (self.glGenTextures_p)(n, textures)
   }
   /// [glGenVertexArrays](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGenVertexArrays.xhtml)
   #[inline]
-  pub unsafe fn GenVertexArrays(&self, n: GLsizei, arrays: *mut GLuint)  {
+  pub unsafe fn GenVertexArrays(&self, n: GLsizei, arrays: *mut GLuint) {
     (self.glGenVertexArrays_p)(n, arrays)
   }
   /// [glGenerateMipmap](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGenerateMipmap.xhtml)
   #[inline]
-  pub fn GenerateMipmap(&self, target: GLenum)  {
+  pub fn GenerateMipmap(&self, target: GLenum) {
     (self.glGenerateMipmap_p)(target)
   }
   /// [glGetError](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetError.xhtml)
   #[inline]
-  pub fn GetError(&self, ) -> GLenum {
+  pub fn GetError(&self) -> GLenum {
     (self.glGetError_p)()
   }
   /// [glGetFloatv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGet.xhtml)
   #[inline]
-  pub unsafe fn GetFloatv(&self, pname: GLenum, data: *mut GLfloat)  {
+  pub unsafe fn GetFloatv(&self, pname: GLenum, data: *mut GLfloat) {
     (self.glGetFloatv_p)(pname, data)
   }
   /// [glGetIntegerv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGet.xhtml)
   #[inline]
-  pub unsafe fn GetIntegerv(&self, pname: GLenum, data: *mut GLint)  {
+  pub unsafe fn GetIntegerv(&self, pname: GLenum, data: *mut GLint) {
     (self.glGetIntegerv_p)(pname, data)
   }
   /// [glGetProgramInfoLog](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetProgramInfoLog.xhtml)
   #[inline]
-  pub unsafe fn GetProgramInfoLog(&self, program: GLuint, maxLength: GLsizei, length: *mut GLsizei, infoLog: *mut GLchar)  {
+  pub unsafe fn GetProgramInfoLog(
+    &self, program: GLuint, maxLength: GLsizei, length: *mut GLsizei,
+    infoLog: *mut GLchar,
+  ) {
     (self.glGetProgramInfoLog_p)(program, maxLength, length, infoLog)
   }
   /// [glGetProgramiv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetProgram.xhtml)
   #[inline]
-  pub unsafe fn GetProgramiv(&self, program: GLuint, pname: GLenum, params: *mut GLint)  {
+  pub unsafe fn GetProgramiv(
+    &self, program: GLuint, pname: GLenum, params: *mut GLint,
+  ) {
     (self.glGetProgramiv_p)(program, pname, params)
   }
   /// [glGetShaderInfoLog](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetShaderInfoLog.xhtml)
   #[inline]
-  pub unsafe fn GetShaderInfoLog(&self, shader: GLuint, maxLength: GLsizei, length: *mut GLsizei, infoLog: *mut GLchar)  {
+  pub unsafe fn GetShaderInfoLog(
+    &self, shader: GLuint, maxLength: GLsizei, length: *mut GLsizei,
+    infoLog: *mut GLchar,
+  ) {
     (self.glGetShaderInfoLog_p)(shader, maxLength, length, infoLog)
   }
   /// [glGetShaderiv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetShader.xhtml)
   #[inline]
-  pub unsafe fn GetShaderiv(&self, shader: GLuint, pname: GLenum, params: *mut GLint)  {
+  pub unsafe fn GetShaderiv(
+    &self, shader: GLuint, pname: GLenum, params: *mut GLint,
+  ) {
     (self.glGetShaderiv_p)(shader, pname, params)
   }
   /// [glGetString](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetString.xhtml)
@@ -600,178 +670,276 @@ impl GlFns {
   }
   /// [glGetUniformBlockIndex](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetUniformBlockIndex.xhtml)
   #[inline]
-  pub unsafe fn GetUniformBlockIndex(&self, program: GLuint, uniformBlockName: *const GLchar) -> GLuint {
+  pub unsafe fn GetUniformBlockIndex(
+    &self, program: GLuint, uniformBlockName: *const GLchar,
+  ) -> GLuint {
     (self.glGetUniformBlockIndex_p)(program, uniformBlockName)
   }
   /// [glGetUniformLocation](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glGetUniformLocation.xhtml)
   #[inline]
-  pub unsafe fn GetUniformLocation(&self, program: GLuint, name: *const GLchar) -> GLint {
+  pub unsafe fn GetUniformLocation(
+    &self, program: GLuint, name: *const GLchar,
+  ) -> GLint {
     (self.glGetUniformLocation_p)(program, name)
   }
   /// [glLinkProgram](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glLinkProgram.xhtml)
   #[inline]
-  pub fn LinkProgram(&self, program: GLuint)  {
+  pub fn LinkProgram(&self, program: GLuint) {
     (self.glLinkProgram_p)(program)
   }
   /// [glPixelStorei](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glPixelStore.xhtml)
   #[inline]
-  pub fn PixelStorei(&self, pname: GLenum, param: GLint)  {
+  pub fn PixelStorei(&self, pname: GLenum, param: GLint) {
     (self.glPixelStorei_p)(pname, param)
   }
   /// [glPolygonMode](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glPolygonMode.xhtml)
   #[inline]
-  pub fn PolygonMode(&self, face: GLenum, mode: GLenum)  {
+  pub fn PolygonMode(&self, face: GLenum, mode: GLenum) {
     (self.glPolygonMode_p)(face, mode)
   }
   /// [glReadBuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glReadBuffer.xhtml)
   #[inline]
-  pub fn ReadBuffer(&self, mode: GLenum)  {
+  pub fn ReadBuffer(&self, mode: GLenum) {
     (self.glReadBuffer_p)(mode)
   }
   /// [glRenderbufferStorage](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glRenderbufferStorage.xhtml)
   #[inline]
-  pub fn RenderbufferStorage(&self, target: GLenum, internalformat: GLenum, width: GLsizei, height: GLsizei)  {
+  pub fn RenderbufferStorage(
+    &self, target: GLenum, internalformat: GLenum, width: GLsizei,
+    height: GLsizei,
+  ) {
     (self.glRenderbufferStorage_p)(target, internalformat, width, height)
   }
   /// [glRenderbufferStorageMultisample](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glRenderbufferStorageMultisample.xhtml)
   #[inline]
-  pub fn RenderbufferStorageMultisample(&self, target: GLenum, samples: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei)  {
-    (self.glRenderbufferStorageMultisample_p)(target, samples, internalformat, width, height)
+  pub fn RenderbufferStorageMultisample(
+    &self, target: GLenum, samples: GLsizei, internalformat: GLenum,
+    width: GLsizei, height: GLsizei,
+  ) {
+    (self.glRenderbufferStorageMultisample_p)(
+      target,
+      samples,
+      internalformat,
+      width,
+      height,
+    )
   }
   /// [glShaderSource](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glShaderSource.xhtml)
   #[inline]
-  pub unsafe fn ShaderSource(&self, shader: GLuint, count: GLsizei, string: *const *mut GLchar, length: *const GLint)  {
+  pub unsafe fn ShaderSource(
+    &self, shader: GLuint, count: GLsizei, string: *const *mut GLchar,
+    length: *const GLint,
+  ) {
     (self.glShaderSource_p)(shader, count, string, length)
   }
   /// [glStencilFunc](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glStencilFunc.xhtml)
   #[inline]
-  pub fn StencilFunc(&self, func: GLenum, ref_: GLint, mask: GLuint)  {
+  pub fn StencilFunc(&self, func: GLenum, ref_: GLint, mask: GLuint) {
     (self.glStencilFunc_p)(func, ref_, mask)
   }
   /// [glStencilMask](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glStencilMask.xhtml)
   #[inline]
-  pub fn StencilMask(&self, mask: GLuint)  {
+  pub fn StencilMask(&self, mask: GLuint) {
     (self.glStencilMask_p)(mask)
   }
   /// [glStencilOp](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glStencilOp.xhtml)
   #[inline]
-  pub fn StencilOp(&self, sfail: GLenum, dpfail: GLenum, dppass: GLenum)  {
+  pub fn StencilOp(&self, sfail: GLenum, dpfail: GLenum, dppass: GLenum) {
     (self.glStencilOp_p)(sfail, dpfail, dppass)
   }
   /// [glTexImage2D](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glTexImage2D.xhtml)
   #[inline]
-  pub unsafe fn TexImage2D(&self, target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type_: GLenum, data: *const void)  {
-    (self.glTexImage2D_p)(target, level, internalformat, width, height, border, format, type_, data)
+  pub unsafe fn TexImage2D(
+    &self, target: GLenum, level: GLint, internalformat: GLint, width: GLsizei,
+    height: GLsizei, border: GLint, format: GLenum, type_: GLenum,
+    data: *const void,
+  ) {
+    (self.glTexImage2D_p)(
+      target,
+      level,
+      internalformat,
+      width,
+      height,
+      border,
+      format,
+      type_,
+      data,
+    )
   }
   /// [glTexImage2DMultisample](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glTexImage2DMultisample.xhtml)
   #[inline]
-  pub fn TexImage2DMultisample(&self, target: GLenum, samples: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei, fixedsamplelocations: GLboolean)  {
-    (self.glTexImage2DMultisample_p)(target, samples, internalformat, width, height, fixedsamplelocations)
+  pub fn TexImage2DMultisample(
+    &self, target: GLenum, samples: GLsizei, internalformat: GLenum,
+    width: GLsizei, height: GLsizei, fixedsamplelocations: GLboolean,
+  ) {
+    (self.glTexImage2DMultisample_p)(
+      target,
+      samples,
+      internalformat,
+      width,
+      height,
+      fixedsamplelocations,
+    )
   }
   /// [glTexImage3D](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glTexImage3D.xhtml)
   #[inline]
-  pub unsafe fn TexImage3D(&self, target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type_: GLenum, data: *const void)  {
-    (self.glTexImage3D_p)(target, level, internalformat, width, height, depth, border, format, type_, data)
+  pub unsafe fn TexImage3D(
+    &self, target: GLenum, level: GLint, internalformat: GLint, width: GLsizei,
+    height: GLsizei, depth: GLsizei, border: GLint, format: GLenum,
+    type_: GLenum, data: *const void,
+  ) {
+    (self.glTexImage3D_p)(
+      target,
+      level,
+      internalformat,
+      width,
+      height,
+      depth,
+      border,
+      format,
+      type_,
+      data,
+    )
   }
   /// [glTexParameterfv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glTexParameter.xhtml)
   #[inline]
-  pub unsafe fn TexParameterfv(&self, target: GLenum, pname: GLenum, params: *const GLfloat)  {
+  pub unsafe fn TexParameterfv(
+    &self, target: GLenum, pname: GLenum, params: *const GLfloat,
+  ) {
     (self.glTexParameterfv_p)(target, pname, params)
   }
   /// [glTexParameteri](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glTexParameter.xhtml)
   #[inline]
-  pub fn TexParameteri(&self, target: GLenum, pname: GLenum, param: GLint)  {
+  pub fn TexParameteri(&self, target: GLenum, pname: GLenum, param: GLint) {
     (self.glTexParameteri_p)(target, pname, param)
   }
   /// [glUniform1f](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub fn Uniform1f(&self, location: GLint, v0: GLfloat)  {
+  pub fn Uniform1f(&self, location: GLint, v0: GLfloat) {
     (self.glUniform1f_p)(location, v0)
   }
   /// [glUniform1fv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn Uniform1fv(&self, location: GLint, count: GLsizei, value: *const [GLfloat; 1])  {
+  pub unsafe fn Uniform1fv(
+    &self, location: GLint, count: GLsizei, value: *const [GLfloat; 1],
+  ) {
     (self.glUniform1fv_p)(location, count, value)
   }
   /// [glUniform1i](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub fn Uniform1i(&self, location: GLint, v0: GLint)  {
+  pub fn Uniform1i(&self, location: GLint, v0: GLint) {
     (self.glUniform1i_p)(location, v0)
   }
   /// [glUniform1iv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn Uniform1iv(&self, location: GLint, count: GLsizei, value: *const GLint)  {
+  pub unsafe fn Uniform1iv(
+    &self, location: GLint, count: GLsizei, value: *const GLint,
+  ) {
     (self.glUniform1iv_p)(location, count, value)
   }
   /// [glUniform2f](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub fn Uniform2f(&self, location: GLint, v0: GLfloat, v1: GLfloat)  {
+  pub fn Uniform2f(&self, location: GLint, v0: GLfloat, v1: GLfloat) {
     (self.glUniform2f_p)(location, v0, v1)
   }
   /// [glUniform2fv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn Uniform2fv(&self, location: GLint, count: GLsizei, value: *const [GLfloat; 2])  {
+  pub unsafe fn Uniform2fv(
+    &self, location: GLint, count: GLsizei, value: *const [GLfloat; 2],
+  ) {
     (self.glUniform2fv_p)(location, count, value)
   }
   /// [glUniform3f](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub fn Uniform3f(&self, location: GLint, v0: GLfloat, v1: GLfloat, v2: GLfloat)  {
+  pub fn Uniform3f(
+    &self, location: GLint, v0: GLfloat, v1: GLfloat, v2: GLfloat,
+  ) {
     (self.glUniform3f_p)(location, v0, v1, v2)
   }
   /// [glUniform3fv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn Uniform3fv(&self, location: GLint, count: GLsizei, value: *const [GLfloat; 3])  {
+  pub unsafe fn Uniform3fv(
+    &self, location: GLint, count: GLsizei, value: *const [GLfloat; 3],
+  ) {
     (self.glUniform3fv_p)(location, count, value)
   }
   /// [glUniform4f](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub fn Uniform4f(&self, location: GLint, v0: GLfloat, v1: GLfloat, v2: GLfloat, v3: GLfloat)  {
+  pub fn Uniform4f(
+    &self, location: GLint, v0: GLfloat, v1: GLfloat, v2: GLfloat, v3: GLfloat,
+  ) {
     (self.glUniform4f_p)(location, v0, v1, v2, v3)
   }
   /// [glUniform4fv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn Uniform4fv(&self, location: GLint, count: GLsizei, value: *const [GLfloat; 4])  {
+  pub unsafe fn Uniform4fv(
+    &self, location: GLint, count: GLsizei, value: *const [GLfloat; 4],
+  ) {
     (self.glUniform4fv_p)(location, count, value)
   }
   /// [glUniformBlockBinding](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniformBlockBinding.xhtml)
   #[inline]
-  pub unsafe fn UniformBlockBinding(&self, program: GLuint, uniformBlockIndex: GLuint, uniformBlockBinding: GLuint)  {
-    (self.glUniformBlockBinding_p)(program, uniformBlockIndex, uniformBlockBinding)
+  pub unsafe fn UniformBlockBinding(
+    &self, program: GLuint, uniformBlockIndex: GLuint,
+    uniformBlockBinding: GLuint,
+  ) {
+    (self.glUniformBlockBinding_p)(
+      program,
+      uniformBlockIndex,
+      uniformBlockBinding,
+    )
   }
   /// [glUniformMatrix2fv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn UniformMatrix2fv(&self, location: GLint, count: GLsizei, transpose: GLboolean, value: *const [GLfloat; 4])  {
+  pub unsafe fn UniformMatrix2fv(
+    &self, location: GLint, count: GLsizei, transpose: GLboolean,
+    value: *const [GLfloat; 4],
+  ) {
     (self.glUniformMatrix2fv_p)(location, count, transpose, value)
   }
   /// [glUniformMatrix3fv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn UniformMatrix3fv(&self, location: GLint, count: GLsizei, transpose: GLboolean, value: *const [GLfloat; 9])  {
+  pub unsafe fn UniformMatrix3fv(
+    &self, location: GLint, count: GLsizei, transpose: GLboolean,
+    value: *const [GLfloat; 9],
+  ) {
     (self.glUniformMatrix3fv_p)(location, count, transpose, value)
   }
   /// [glUniformMatrix4fv](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUniform.xhtml)
   #[inline]
-  pub unsafe fn UniformMatrix4fv(&self, location: GLint, count: GLsizei, transpose: GLboolean, value: *const [GLfloat; 16])  {
+  pub unsafe fn UniformMatrix4fv(
+    &self, location: GLint, count: GLsizei, transpose: GLboolean,
+    value: *const [GLfloat; 16],
+  ) {
     (self.glUniformMatrix4fv_p)(location, count, transpose, value)
   }
   /// [glUseProgram](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glUseProgram.xhtml)
   #[inline]
-  pub fn UseProgram(&self, program: GLuint)  {
+  pub fn UseProgram(&self, program: GLuint) {
     (self.glUseProgram_p)(program)
   }
   /// [glVertexAttribDivisor](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glVertexAttribDivisor.xhtml) (GL 3.3)
   #[inline]
-  pub fn VertexAttribDivisor(&self, index: GLuint, divisor: GLuint)  {
+  pub fn VertexAttribDivisor(&self, index: GLuint, divisor: GLuint) {
     (self.glVertexAttribDivisor_p)(index, divisor)
   }
   /// [glVertexAttribIPointer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glVertexAttribPointer.xhtml)
   #[inline]
-  pub unsafe fn VertexAttribIPointer(&self, index: GLuint, size: GLint, type_: GLenum, stride: GLsizei, pointer: *const void)  {
+  pub unsafe fn VertexAttribIPointer(
+    &self, index: GLuint, size: GLint, type_: GLenum, stride: GLsizei,
+    pointer: *const void,
+  ) {
     (self.glVertexAttribIPointer_p)(index, size, type_, stride, pointer)
   }
   /// [glVertexAttribPointer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glVertexAttribPointer.xhtml)
   #[inline]
-  pub unsafe fn VertexAttribPointer(&self, index: GLuint, size: GLint, type_: GLenum, normalized: GLboolean, stride: GLsizei, pointer: *const void)  {
-    (self.glVertexAttribPointer_p)(index, size, type_, normalized, stride, pointer)
+  pub unsafe fn VertexAttribPointer(
+    &self, index: GLuint, size: GLint, type_: GLenum, normalized: GLboolean,
+    stride: GLsizei, pointer: *const void,
+  ) {
+    (self.glVertexAttribPointer_p)(
+      index, size, type_, normalized, stride, pointer,
+    )
   }
   /// [glViewport](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glViewport.xhtml) (GL 1.0, GLES 2.0)
   ///
@@ -786,9 +954,9 @@ impl GlFns {
   ///
   /// * `x` and `y` specify the lower left corner of the viewport rectangle, in
   ///   pixels. The initial value is (0,0).
-  /// * `width` and `height` specify the width and height of the viewport. When a
-  ///   GL context is first attached to a window, width and height are set to the
-  ///   dimensions of that window.
+  /// * `width` and `height` specify the width and height of the viewport. When
+  ///   a GL context is first attached to a window, width and height are set to
+  ///   the dimensions of that window.
   ///
   /// ## Errors
   /// * `GL_INVALID_VALUE` is generated if either `width` or `height` are
@@ -798,7 +966,7 @@ impl GlFns {
   /// * `GL_VIEWPORT`
   /// * `GL_MAX_VIEWPORT_DIMS`
   #[inline]
-  pub fn Viewport(&self, x: GLint, y: GLint, width: GLsizei, height: GLsizei)  {
+  pub fn Viewport(&self, x: GLint, y: GLint, width: GLsizei, height: GLsizei) {
     (self.glViewport_p)(x, y, width, height)
   }
 }
